==> dde-launchpad_1.99.0.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Kiinnitä ylös</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Siirrä ylös</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Poista suosikeista</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Lisää suosikkeihin</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Kiinnitä työpöydälle</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Poista työpöydältä</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Poista telakasta</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Kiinnitä telakkaan</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Lisää käynnistykseen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Poista käynnistyksestä</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Käytä välityspalvelinta</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Poista näytön skaalaus käytöstä</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="32"/>
        <source>Power</source>
        <translation>Virta</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="56"/>
        <source>Search</source>
        <translation>Hae</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="103"/>
        <source>Full-screen Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Asenna</translation>
    </message>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Usein käytetty</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="152"/>
        <source>Window Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Näytä käynnistin (oletuksena piilotettu)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Vaihda käynnistimen näkyvyyttä</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Pikakeskustelu</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Musiikki</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Grafiikka</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Game</source>
        <translation>Peli</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Toimisto</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Lukeminen</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Ohjelmointi</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Järjestelmä</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Muut</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="411"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Haluatko varmasti poistaa asennuksen %1?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="423"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="437"/>
        <source>Confirm</source>
        <translation>Vahvista</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Hiljattain asennettu</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Kaikki sovellukset</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="545"/>
        <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Ei hakutuloksia</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Vapaa lajittelu</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Lajittele luokan mukaan</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Lajittele nimen mukaan</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Tietokone</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Asiakirjat</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Ohjauspaneli</translation>
    </message>
</context>
</TS>

==> dde-launchpad_1.99.1.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Kiinnitä ylös</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Siirrä ylös</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Poista suosikeista</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Lisää suosikkeihin</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Kiinnitä työpöydälle</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Poista työpöydältä</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Poista telakasta</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Kiinnitä telakkaan</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Lisää käynnistykseen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Poista käynnistyksestä</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Käytä välityspalvelinta</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Poista näytön skaalaus</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="32"/>
        <source>Power</source>
        <translation>Virta</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="56"/>
        <source>Search</source>
        <translation>Hae</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="103"/>
        <source>Full-screen Mode</source>
        <translation>Koko näyttö</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Asenna</translation>
    </message>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Usein käytetty</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="152"/>
        <source>Window Mode</source>
        <translation>Ikkunatila</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Näytä käynnistin (oletuksena piilotettu)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Vaihda käynnistimen näkyvyyttä</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Keskustelu</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Musiikki</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Grafiikka</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Game</source>
        <translation>Pelit</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Toimisto</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Lukeminen</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Ohjelmointi</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Järjestelmä</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Muut</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="411"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Haluatko poistaa asennuksen %1?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="423"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="437"/>
        <source>Confirm</source>
        <translation>Vahvista</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Hiljattain asennettu</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Kaikki sovellukset</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="545"/>
        <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Ei hakutuloksia</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Vapaa lajittelu</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Luokan mukaan</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Nimen mukaan</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Lajittelutila</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Tietokone</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Asiakirjat</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Ohjauspaneli</translation>
    </message>
</context>
</TS>
